@@ -9,9 +9,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: constants.py 998 2010-07-07 19:56:08Z pronovic $
 # Purpose  : Provides common constants used by standard actions.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +33,7 @@ Provides common constants used by standard actions.
 DIR_TIME_FORMAT      = "%Y/%m/%d"
 DIGEST_EXTENSION     = "sha"
 
-INDICATOR_PATTERN    = [ "cback\..*", ]
+INDICATOR_PATTERN    = [ r"cback\..*", ]
 COLLECT_INDICATOR    = "cback.collect"
 STAGE_INDICATOR      = "cback.stage"
 STORE_INDICATOR      = "cback.store"
