@@ -212,11 +212,14 @@ def cli():
       _diagnostics()
       return 0
 
-   try:
+   if options.stacktrace:
       logfile = setupLogging(options)
-   except Exception, e:
-      sys.stderr.write("Error setting up logging: %s\n" % e)
-      return 3
+   else:
+      try:
+         logfile = setupLogging(options)
+      except Exception as e:
+         sys.stderr.write("Error setting up logging: %s\n" % e)
+         return 3
 
    logger.info("Cedar Backup run started.")
    logger.info("Options were [%s]", options)
@@ -1064,10 +1067,14 @@ def _setupLogfile(options):
    else:
       logfile = options.logfile
    if not os.path.exists(logfile):
-      if options.mode is None:
-         os.fdopen(os.open(logfile, os.O_RDWR|os.O_CREAT|os.O_APPEND, DEFAULT_MODE), "a+").write("")
-      else:
-         os.fdopen(os.open(logfile, os.O_RDWR|os.O_CREAT|os.O_APPEND, options.mode), "a+").write("")
+      mode = DEFAULT_MODE if options.mode is None else options.mode
+      orig = os.umask(0) # Per os.open(), "When computing mode, the current umask value is first masked out"
+      try:
+         fd = os.open(logfile, os.O_RDWR|os.O_CREAT|os.O_APPEND, mode)
+         with os.fdopen(fd, "a+") as f:
+            f.write("")
+      finally:
+         os.umask(orig)
       try:
          if options.owner is None or len(options.owner) < 2:
             (uid, gid) = getUidGid(DEFAULT_OWNERSHIP[0], DEFAULT_OWNERSHIP[1])
