@@ -25,7 +25,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
 # Purpose  : Provides an extension to check remaining media capacity.
 #
@@ -184,7 +184,7 @@ class CapacityConfig(object):
    def __init__(self, maxPercentage=None, minBytes=None):
       """
       Constructor for the C{CapacityConfig} class.
-      
+
       @param maxPercentage: Maximum percentage of the media that may be utilized
       @param minBytes: Minimum number of free bytes that must be available
       """
@@ -307,7 +307,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -438,7 +438,7 @@ class LocalConfig(object):
    def _parseCapacity(parentNode):
       """
       Parses a capacity configuration section.
-      
+
       We read the following fields::
 
          maxPercentage  //cb_config/capacity/max_percentage
@@ -519,14 +519,14 @@ def executeAction(configPath, options, config):
    if config.store.checkMedia:
       checkMediaState(config.store)  # raises exception if media is not initialized
    capacity = createWriter(config).retrieveCapacity()
-   logger.debug("Media capacity: %s" % capacity)
+   logger.debug("Media capacity: %s", capacity)
    if local.capacity.maxPercentage is not None:
       if capacity.utilized > local.capacity.maxPercentage.percentage:
-         logger.error("Media has reached capacity limit of %s%%: %.2f%% utilized" % 
-                      (local.capacity.maxPercentage.quantity, capacity.utilized))
-   else: # if local.capacity.bytes is not None
-      if capacity.bytesAvailable < local.capacity.minBytes.bytes:
-         logger.error("Media has reached capacity limit of %s: only %s available" % 
-                      (displayBytes(local.capacity.minBytes.bytes), displayBytes(capacity.bytesAvailable)))
+         logger.error("Media has reached capacity limit of %s%%: %.2f%% utilized",
+                      local.capacity.maxPercentage.quantity, capacity.utilized)
+   else:
+      if capacity.bytesAvailable < local.capacity.minBytes:
+         logger.error("Media has reached capacity limit of %s: only %s available",
+                      local.capacity.minBytes, displayBytes(capacity.bytesAvailable))
    logger.info("Executed the capacity extended action successfully.")
 
