@@ -25,7 +25,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
 # Purpose  : Provides an extension to encrypt staging directories.
 #
@@ -220,7 +220,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -353,7 +353,7 @@ class LocalConfig(object):
    def _parseEncrypt(parent):
       """
       Parses an encrypt configuration section.
-      
+
       We read the following individual fields::
 
          encryptMode    //cb_config/encrypt/encrypt_mode
@@ -407,7 +407,7 @@ def executeAction(configPath, options, config):
       _confirmGpgRecipient(local.encrypt.encryptTarget)
    dailyDirs = findDailyDirs(config.stage.targetDir, ENCRYPT_INDICATOR)
    for dailyDir in dailyDirs:
-      _encryptDailyDir(dailyDir, local.encrypt.encryptMode, local.encrypt.encryptTarget, 
+      _encryptDailyDir(dailyDir, local.encrypt.encryptMode, local.encrypt.encryptTarget,
                        config.options.backupUser, config.options.backupGroup)
       writeIndicatorFile(dailyDir, ENCRYPT_INDICATOR, config.options.backupUser, config.options.backupGroup)
    logger.info("Executed the encrypt extended action successfully.")
@@ -433,11 +433,11 @@ def _encryptDailyDir(dailyDir, encryptMode, encryptTarget, backupUser, backupGro
    @raise ValueError: If the encrypt mode is not supported.
    @raise ValueError: If the daily staging directory does not exist.
    """
-   logger.debug("Begin encrypting contents of [%s]." % dailyDir)
+   logger.debug("Begin encrypting contents of [%s].", dailyDir)
    fileList = getBackupFiles(dailyDir) # ignores indicator files
    for path in fileList:
       _encryptFile(path, encryptMode, encryptTarget, backupUser, backupGroup, removeSource=True)
-   logger.debug("Completed encrypting contents of [%s]." % dailyDir)
+   logger.debug("Completed encrypting contents of [%s].", dailyDir)
 
 
 ##########################
@@ -475,10 +475,10 @@ def _encryptFile(sourcePath, encryptMode, encryptTarget, backupUser, backupGroup
    changeOwnership(encryptedPath, backupUser, backupGroup)
    if removeSource:
       if os.path.exists(sourcePath):
-         try: 
+         try:
             os.remove(sourcePath)
-            logger.debug("Completed removing old file [%s]." % sourcePath)
-         except: 
+            logger.debug("Completed removing old file [%s].", sourcePath)
+         except:
             raise IOError("Failed to remove file [%s] after encrypting it." % (sourcePath))
    return encryptedPath
 
@@ -497,7 +497,7 @@ def _encryptFileWithGpg(sourcePath, recipient):
 
    @param sourcePath: Absolute path of file to be encrypted.
    @param recipient: Recipient name to be passed to GPG's C{"-r"} option
-   
+
    @return: Path to the newly-created encrypted file.
 
    @raise IOError: If there is a problem encrypting the file.
@@ -510,9 +510,9 @@ def _encryptFileWithGpg(sourcePath, recipient):
       raise IOError("Error [%d] calling gpg to encrypt [%s]." % (result, sourcePath))
    if not os.path.exists(encryptedPath):
       raise IOError("After call to [%s], encrypted file [%s] does not exist." % (command, encryptedPath))
-   logger.debug("Completed encrypting file [%s] to [%s]." % (sourcePath, encryptedPath))
+   logger.debug("Completed encrypting file [%s] to [%s].", sourcePath, encryptedPath)
    return encryptedPath
-   
+
 
 #################################
 # _confirmGpgRecpient() function
