@@ -25,7 +25,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
 # Purpose  : Provides an extension to back up mbox email files.
 #
@@ -52,7 +52,7 @@ Backing up email
    One solution to this problem is to design a smarter incremental backup process,
    which backs up baseline content on the first day of the week, and then backs up
    only new messages added to that folder on every other day of the week.  This way,
-   the backup for any single day is only as large as the messages placed into the 
+   the backup for any single day is only as large as the messages placed into the
    folder on that day.  The backup isn't as "perfect" as the incremental backup
    process, because it doesn't preserve information about messages deleted from
    the backed-up folder.  However, it should be much more space-efficient, and
@@ -65,8 +65,8 @@ What is this extension?
    This is a Cedar Backup extension used to back up mbox email files via the Cedar
    Backup command line.  Individual mbox files or directories containing mbox
    files can be backed up using the same collect modes allowed for filesystems in
-   the standard Cedar Backup collect action: weekly, daily, incremental.  It 
-   implements the "smart" incremental backup process discussed above, using 
+   the standard Cedar Backup collect action: weekly, daily, incremental.  It
+   implements the "smart" incremental backup process discussed above, using
    functionality provided by the C{grepmail} utility.
 
    This extension requires a new configuration section <mbox> and is intended to
@@ -140,7 +140,7 @@ class MboxFile(object):
       Constructor for the C{MboxFile} class.
 
       You should never directly instantiate this class.
-      
+
       @param absolutePath: Absolute path to an mbox file on disk.
       @param collectMode: Overridden collect mode for this directory.
       @param compressMode: Overridden compression mode for this directory.
@@ -267,7 +267,7 @@ class MboxDir(object):
    we only allow relative exclusions and there is no configured ignore file.
    This is because mbox directory backups are not recursive.
 
-   @sort: __init__, __repr__, __str__, __cmp__, absolutePath, collectMode, 
+   @sort: __init__, __repr__, __str__, __cmp__, absolutePath, collectMode,
           compressMode, relativeExcludePaths, excludePatterns
    """
 
@@ -277,7 +277,7 @@ class MboxDir(object):
       Constructor for the C{MboxDir} class.
 
       You should never directly instantiate this class.
-      
+
       @param absolutePath: Absolute path to a mbox file on disk.
       @param collectMode: Overridden collect mode for this directory.
       @param compressMode: Overridden compression mode for this directory.
@@ -668,7 +668,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -762,8 +762,8 @@ class LocalConfig(object):
       """
       if self.mbox is None:
          raise ValueError("Mbox section is required.")
-      if ((self.mbox.mboxFiles is None or len(self.mbox.mboxFiles) < 1) and \
-          (self.mbox.mboxDirs is None or len(self.mbox.mboxDirs) < 1)):
+      if  (self.mbox.mboxFiles is None or len(self.mbox.mboxFiles) < 1) and \
+          (self.mbox.mboxDirs is None or len(self.mbox.mboxDirs) < 1):
          raise ValueError("At least one mbox file or directory must be configured.")
       if self.mbox.mboxFiles is not None:
          for mboxFile in self.mbox.mboxFiles:
@@ -836,7 +836,7 @@ class LocalConfig(object):
    def _parseMbox(parent):
       """
       Parses an mbox configuration section.
-      
+
       We read the following individual fields::
 
          collectMode    //cb_config/mbox/collect_mode
@@ -875,7 +875,7 @@ class LocalConfig(object):
 
          absolutePath            abs_path
          collectMode             collect_mode
-         compressMode            compess_mode 
+         compressMode            compess_mode
 
       @param parent: Parent node to search beneath.
 
@@ -903,7 +903,7 @@ class LocalConfig(object):
 
          absolutePath            abs_path
          collectMode             collect_mode
-         compressMode            compess_mode 
+         compressMode            compess_mode
 
       We also read groups of the following items, one list element per
       item::
@@ -942,7 +942,7 @@ class LocalConfig(object):
          patterns    exclude/pattern
 
       If there are none of some pattern (i.e. no relative path items) then
-      C{None} will be returned for that item in the tuple.  
+      C{None} will be returned for that item in the tuple.
 
       @param parentNode: Parent node to search beneath.
 
@@ -1056,16 +1056,16 @@ def executeAction(configPath, options, config):
    local = LocalConfig(xmlPath=configPath)
    todayIsStart = isStartOfWeek(config.options.startingDay)
    fullBackup = options.full or todayIsStart
-   logger.debug("Full backup flag is [%s]" % fullBackup)
+   logger.debug("Full backup flag is [%s]", fullBackup)
    if local.mbox.mboxFiles is not None:
       for mboxFile in local.mbox.mboxFiles:
-         logger.debug("Working with mbox file [%s]" % mboxFile.absolutePath)
+         logger.debug("Working with mbox file [%s]", mboxFile.absolutePath)
          collectMode = _getCollectMode(local, mboxFile)
          compressMode = _getCompressMode(local, mboxFile)
          lastRevision = _loadLastRevision(config, mboxFile, fullBackup, collectMode)
          if fullBackup or (collectMode in ['daily', 'incr', ]) or (collectMode == 'weekly' and todayIsStart):
             logger.debug("Mbox file meets criteria to be backed up today.")
-            _backupMboxFile(config, mboxFile.absolutePath, fullBackup, 
+            _backupMboxFile(config, mboxFile.absolutePath, fullBackup,
                             collectMode, compressMode, lastRevision, newRevision)
          else:
             logger.debug("Mbox file will not be backed up, per collect mode.")
@@ -1073,16 +1073,16 @@ def executeAction(configPath, options, config):
             _writeNewRevision(config, mboxFile, newRevision)
    if local.mbox.mboxDirs is not None:
       for mboxDir in local.mbox.mboxDirs:
-         logger.debug("Working with mbox directory [%s]" % mboxDir.absolutePath)
+         logger.debug("Working with mbox directory [%s]", mboxDir.absolutePath)
          collectMode = _getCollectMode(local, mboxDir)
          compressMode = _getCompressMode(local, mboxDir)
          lastRevision = _loadLastRevision(config, mboxDir, fullBackup, collectMode)
          (excludePaths, excludePatterns) = _getExclusions(mboxDir)
          if fullBackup or (collectMode in ['daily', 'incr', ]) or (collectMode == 'weekly' and todayIsStart):
             logger.debug("Mbox directory meets criteria to be backed up today.")
-            _backupMboxDir(config, mboxDir.absolutePath, 
-                           fullBackup, collectMode, compressMode, 
-                           lastRevision, newRevision, 
+            _backupMboxDir(config, mboxDir.absolutePath,
+                           fullBackup, collectMode, compressMode,
+                           lastRevision, newRevision,
                            excludePaths, excludePatterns)
          else:
             logger.debug("Mbox directory will not be backed up, per collect mode.")
@@ -1092,7 +1092,7 @@ def executeAction(configPath, options, config):
 
 def _getCollectMode(local, item):
    """
-   Gets the collect mode that should be used for an mbox file or directory. 
+   Gets the collect mode that should be used for an mbox file or directory.
    Use file- or directory-specific value if possible, otherwise take from mbox section.
    @param local: LocalConfig object.
    @param item: Mbox file or directory
@@ -1102,7 +1102,7 @@ def _getCollectMode(local, item):
       collectMode = local.mbox.collectMode
    else:
       collectMode = item.collectMode
-   logger.debug("Collect mode is [%s]" % collectMode)
+   logger.debug("Collect mode is [%s]", collectMode)
    return collectMode
 
 def _getCompressMode(local, item):
@@ -1117,7 +1117,7 @@ def _getCompressMode(local, item):
       compressMode = local.mbox.compressMode
    else:
       compressMode = item.compressMode
-   logger.debug("Compress mode is [%s]" % compressMode)
+   logger.debug("Compress mode is [%s]", compressMode)
    return compressMode
 
 def _getRevisionPath(config, item):
@@ -1130,7 +1130,7 @@ def _getRevisionPath(config, item):
    normalized = buildNormalizedPath(item.absolutePath)
    filename = "%s.%s" % (normalized, REVISION_PATH_EXTENSION)
    revisionPath = os.path.join(config.options.workingDir, filename)
-   logger.debug("Revision file path is [%s]" % revisionPath)
+   logger.debug("Revision file path is [%s]", revisionPath)
    return revisionPath
 
 def _loadLastRevision(config, item, fullBackup, collectMode):
@@ -1158,19 +1158,19 @@ def _loadLastRevision(config, item, fullBackup, collectMode):
       logger.debug("Revision file ignored because this is a full backup.")
    elif collectMode in ['weekly', 'daily']:
       revisionDate = None
-      logger.debug("No revision file based on collect mode [%s]." % collectMode)
+      logger.debug("No revision file based on collect mode [%s].", collectMode)
    else:
       logger.debug("Revision file will be used for non-full incremental backup.")
       if not os.path.isfile(revisionPath):
          revisionDate = None
-         logger.debug("Revision file [%s] does not exist on disk." % revisionPath)
+         logger.debug("Revision file [%s] does not exist on disk.", revisionPath)
       else:
          try:
             revisionDate = pickle.load(open(revisionPath, "r"))
-            logger.debug("Loaded revision file [%s] from disk: [%s]" % (revisionPath, revisionDate))
+            logger.debug("Loaded revision file [%s] from disk: [%s]", revisionPath, revisionDate)
          except:
             revisionDate = None
-            logger.error("Failed loading revision file [%s] from disk." % revisionPath)
+            logger.error("Failed loading revision file [%s] from disk.", revisionPath)
    return revisionDate
 
 def _writeNewRevision(config, item, newRevision):
@@ -1192,9 +1192,9 @@ def _writeNewRevision(config, item, newRevision):
    try:
       pickle.dump(newRevision, open(revisionPath, "w"))
       changeOwnership(revisionPath, config.options.backupUser, config.options.backupGroup)
-      logger.debug("Wrote new revision file [%s] to disk: [%s]" % (revisionPath, newRevision))
+      logger.debug("Wrote new revision file [%s] to disk: [%s]", revisionPath, newRevision)
    except:
-      logger.error("Failed to write revision file [%s] to disk." % revisionPath)
+      logger.error("Failed to write revision file [%s] to disk.", revisionPath)
 
 def _getExclusions(mboxDir):
    """
@@ -1203,7 +1203,7 @@ def _getExclusions(mboxDir):
    The returned files value is a list of absolute paths to be excluded from the
    backup for a given directory.  It is derived from the mbox directory's
    relative exclude paths.
-   
+
    The returned patterns value is a list of patterns to be excluded from the
    backup for a given directory.  It is derived from the mbox directory's list
    of patterns.
@@ -1219,8 +1219,8 @@ def _getExclusions(mboxDir):
    patterns = []
    if mboxDir.excludePatterns is not None:
       patterns.extend(mboxDir.excludePatterns)
-   logger.debug("Exclude paths: %s" % paths)
-   logger.debug("Exclude patterns: %s" % patterns)
+   logger.debug("Exclude paths: %s", paths)
+   logger.debug("Exclude patterns: %s", patterns)
    return(paths, patterns)
 
 def _getBackupPath(config, mboxPath, compressMode, newRevision, targetDir=None):
@@ -1257,7 +1257,7 @@ def _getBackupPath(config, mboxPath, compressMode, newRevision, targetDir=None):
       backupPath = os.path.join(config.collect.targetDir, filename)
    else:
       backupPath = os.path.join(targetDir, filename)
-   logger.debug("Backup file path is [%s]" % backupPath)
+   logger.debug("Backup file path is [%s]", backupPath)
    return backupPath
 
 def _getTarfilePath(config, mboxPath, compressMode, newRevision):
@@ -1291,7 +1291,7 @@ def _getTarfilePath(config, mboxPath, compressMode, newRevision):
    else:
       archiveMode = "tar"
    tarfilePath = os.path.join(config.collect.targetDir, filename)
-   logger.debug("Tarfile path is [%s]" % tarfilePath)
+   logger.debug("Tarfile path is [%s]", tarfilePath)
    return (tarfilePath, archiveMode)
 
 def _getOutputFile(backupPath, compressMode):
@@ -1314,8 +1314,8 @@ def _getOutputFile(backupPath, compressMode):
    else:
       return open(backupPath, "w")
 
-def _backupMboxFile(config, absolutePath, 
-                    fullBackup, collectMode, compressMode, 
+def _backupMboxFile(config, absolutePath,
+                    fullBackup, collectMode, compressMode,
                     lastRevision, newRevision, targetDir=None):
    """
    Backs up an individual mbox file.
@@ -1328,7 +1328,7 @@ def _backupMboxFile(config, absolutePath,
    @param lastRevision: Date of last backup as datetime.datetime
    @param newRevision: Date of new (current) backup as datetime.datetime
    @param targetDir: Target directory to write the backed-up file into
-    
+
    @raise ValueError: If some value is missing or invalid.
    @raise IOError: If there is a problem backing up the mbox file.
    """
@@ -1343,12 +1343,12 @@ def _backupMboxFile(config, absolutePath,
    result = executeCommand(command, args, returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=outputFile)[0]
    if result != 0:
       raise IOError("Error [%d] executing grepmail on [%s]." % (result, absolutePath))
-   logger.debug("Completed backing up mailbox [%s]." % absolutePath)
+   logger.debug("Completed backing up mailbox [%s].", absolutePath)
    return backupPath
 
-def _backupMboxDir(config, absolutePath, 
+def _backupMboxDir(config, absolutePath,
                    fullBackup, collectMode, compressMode,
-                   lastRevision, newRevision, 
+                   lastRevision, newRevision,
                    excludePaths, excludePatterns):
    """
    Backs up a directory containing mbox files.
@@ -1362,7 +1362,7 @@ def _backupMboxDir(config, absolutePath,
    @param newRevision: Date of new (current) backup as datetime.datetime
    @param excludePaths: List of absolute paths to exclude.
    @param excludePatterns: List of patterns to exclude.
-    
+
    @raise ValueError: If some value is missing or invalid.
    @raise IOError: If there is a problem backing up the mbox file.
    """
@@ -1375,15 +1375,15 @@ def _backupMboxDir(config, absolutePath,
       mboxList.addDirContents(absolutePath, recursive=False)
       tarList = BackupFileList()
       for item in mboxList:
-         backupPath = _backupMboxFile(config, item, fullBackup, 
+         backupPath = _backupMboxFile(config, item, fullBackup,
                                       collectMode, "none",  # no need to compress inside compressed tar
-                                      lastRevision, newRevision, 
+                                      lastRevision, newRevision,
                                       targetDir=tmpdir)
          tarList.addFile(backupPath)
       (tarfilePath, archiveMode) = _getTarfilePath(config, absolutePath, compressMode, newRevision)
       tarList.generateTarfile(tarfilePath, archiveMode, ignore=True, flat=True)
-      changeOwnership(tarfilePath, config.options.backupUser, config.options.backupGroup) 
-      logger.debug("Completed backing up directory [%s]." % absolutePath)
+      changeOwnership(tarfilePath, config.options.backupUser, config.options.backupGroup)
+      logger.debug("Completed backing up directory [%s].", absolutePath)
    finally:
       try:
          for item in tarList:
