@@ -25,7 +25,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Official Cedar Backup Extensions
 # Purpose  : Provides an extension to back up Subversion repositories.
 #
@@ -41,7 +41,7 @@ Provides an extension to back up Subversion repositories.
 This is a Cedar Backup extension used to back up Subversion repositories via
 the Cedar Backup command line.  Each Subversion repository can be backed using
 the same collect modes allowed for filesystems in the standard Cedar Backup
-collect action: weekly, daily, incremental.  
+collect action: weekly, daily, incremental.
 
 This extension requires a new configuration section <subversion> and is
 intended to be run either immediately before or immediately after the standard
@@ -57,11 +57,11 @@ incremental mode.
 
 It turns out that FSFS repositories can also be backed up just like any
 other filesystem directory.  If you would rather do that, then use the normal
-collect action.  This is probably simpler, although it carries its own 
+collect action.  This is probably simpler, although it carries its own
 advantages and disadvantages (plus you will have to be careful to exclude
 the working directories Subversion uses when building an update to commit).
 Check the Subversion documentation for more information.
- 
+
 @author: Kenneth J. Pronovici <pronovic@ieee.org>
 """
 
@@ -155,7 +155,7 @@ class RepositoryDir(object):
       """
       Official string representation for class instance.
       """
-      return "RepositoryDir(%s, %s, %s, %s, %s, %s)" % (self.repositoryType, self.directoryPath, self.collectMode, 
+      return "RepositoryDir(%s, %s, %s, %s, %s, %s)" % (self.repositoryType, self.directoryPath, self.collectMode,
                                                         self.compressMode, self.relativeExcludePaths, self.excludePatterns)
 
    def __str__(self):
@@ -690,7 +690,7 @@ class LocalConfig(object):
 
       @note: It is strongly suggested that the C{validate} option always be set
       to C{True} (the default) unless there is a specific need to read in
-      invalid configuration from disk.  
+      invalid configuration from disk.
 
       @param xmlData: XML data representing configuration.
       @type xmlData: String data.
@@ -855,7 +855,7 @@ class LocalConfig(object):
    def _parseSubversion(parent):
       """
       Parses a subversion configuration section.
-      
+
       We read the following individual fields::
 
          collectMode    //cb_config/subversion/collect_mode
@@ -895,7 +895,7 @@ class LocalConfig(object):
          repositoryType          type
          repositoryPath          abs_path
          collectMode             collect_mode
-         compressMode            compess_mode 
+         compressMode            compess_mode
 
       The type field is optional, and its value is kept around only for
       reference.
@@ -957,7 +957,7 @@ class LocalConfig(object):
          repositoryType          type
          directoryPath           abs_path
          collectMode             collect_mode
-         compressMode            compess_mode 
+         compressMode            compess_mode
 
       We also read groups of the following items, one list element per
       item::
@@ -965,7 +965,7 @@ class LocalConfig(object):
          relativeExcludePaths    exclude/rel_path
          excludePatterns         exclude/pattern
 
-      The exclusions are parsed by L{_parseExclusions}. 
+      The exclusions are parsed by L{_parseExclusions}.
 
       The type field is optional, and its value is kept around only for
       reference.
@@ -1088,18 +1088,18 @@ def executeAction(configPath, options, config):
    local = LocalConfig(xmlPath=configPath)
    todayIsStart = isStartOfWeek(config.options.startingDay)
    fullBackup = options.full or todayIsStart
-   logger.debug("Full backup flag is [%s]" % fullBackup)
+   logger.debug("Full backup flag is [%s]", fullBackup)
    if local.subversion.repositories is not None:
       for repository in local.subversion.repositories:
          _backupRepository(config, local, todayIsStart, fullBackup, repository)
    if local.subversion.repositoryDirs is not None:
       for repositoryDir in local.subversion.repositoryDirs:
-         logger.debug("Working with repository directory [%s]." % repositoryDir.directoryPath)
+         logger.debug("Working with repository directory [%s].", repositoryDir.directoryPath)
          for repositoryPath in _getRepositoryPaths(repositoryDir):
-            repository = Repository(repositoryDir.repositoryType, repositoryPath, 
+            repository = Repository(repositoryDir.repositoryType, repositoryPath,
                                     repositoryDir.collectMode, repositoryDir.compressMode)
             _backupRepository(config, local, todayIsStart, fullBackup, repository)
-         logger.info("Completed backing up Subversion repository directory [%s]." % repositoryDir.directoryPath)
+         logger.info("Completed backing up Subversion repository directory [%s].", repositoryDir.directoryPath)
    logger.info("Executed the Subversion extended action successfully.")
 
 def _getCollectMode(local, repository):
@@ -1113,7 +1113,7 @@ def _getCollectMode(local, repository):
       collectMode = local.subversion.collectMode
    else:
       collectMode = repository.collectMode
-   logger.debug("Collect mode is [%s]" % collectMode)
+   logger.debug("Collect mode is [%s]", collectMode)
    return collectMode
 
 def _getCompressMode(local, repository):
@@ -1128,7 +1128,7 @@ def _getCompressMode(local, repository):
       compressMode = local.subversion.compressMode
    else:
       compressMode = repository.compressMode
-   logger.debug("Compress mode is [%s]" % compressMode)
+   logger.debug("Compress mode is [%s]", compressMode)
    return compressMode
 
 def _getRevisionPath(config, repository):
@@ -1141,7 +1141,7 @@ def _getRevisionPath(config, repository):
    normalized = buildNormalizedPath(repository.repositoryPath)
    filename = "%s.%s" % (normalized, REVISION_PATH_EXTENSION)
    revisionPath = os.path.join(config.options.workingDir, filename)
-   logger.debug("Revision file path is [%s]" % revisionPath)
+   logger.debug("Revision file path is [%s]", revisionPath)
    return revisionPath
 
 def _getBackupPath(config, repositoryPath, compressMode, startRevision, endRevision):
@@ -1161,7 +1161,7 @@ def _getBackupPath(config, repositoryPath, compressMode, startRevision, endRevis
    elif compressMode == 'bzip2':
       filename = "%s.bz2" % filename
    backupPath = os.path.join(config.collect.targetDir, filename)
-   logger.debug("Backup file path is [%s]" % backupPath)
+   logger.debug("Backup file path is [%s]", backupPath)
    return backupPath
 
 def _getRepositoryPaths(repositoryDir):
@@ -1185,7 +1185,7 @@ def _getExclusions(repositoryDir):
    The returned files value is a list of absolute paths to be excluded from the
    backup for a given directory.  It is derived from the repository directory's
    relative exclude paths.
-   
+
    The returned patterns value is a list of patterns to be excluded from the
    backup for a given directory.  It is derived from the repository directory's
    list of patterns.
@@ -1201,8 +1201,8 @@ def _getExclusions(repositoryDir):
    patterns = []
    if repositoryDir.excludePatterns is not None:
       patterns.extend(repositoryDir.excludePatterns)
-   logger.debug("Exclude paths: %s" % paths)
-   logger.debug("Exclude patterns: %s" % patterns)
+   logger.debug("Exclude paths: %s", paths)
+   logger.debug("Exclude patterns: %s", patterns)
    return(paths, patterns)
 
 def _backupRepository(config, local, todayIsStart, fullBackup, repository):
@@ -1216,13 +1216,13 @@ def _backupRepository(config, local, todayIsStart, fullBackup, repository):
    @param local: Local configuration
    @param todayIsStart: Indicates whether today is start of week
    @param fullBackup: Full backup flag
-   @param repository: Repository to operate on 
-    
+   @param repository: Repository to operate on
+
    @raise ValueError: If some value is missing or invalid.
    @raise IOError: If there is a problem executing the Subversion dump.
    """
-   logger.debug("Working with repository [%s]" % repository.repositoryPath)
-   logger.debug("Repository type is [%s]" % repository.repositoryType)
+   logger.debug("Working with repository [%s]", repository.repositoryPath)
+   logger.debug("Repository type is [%s]", repository.repositoryType)
    collectMode = _getCollectMode(local, repository)
    compressMode = _getCompressMode(local, repository)
    revisionPath = _getRevisionPath(config, repository)
@@ -1233,7 +1233,7 @@ def _backupRepository(config, local, todayIsStart, fullBackup, repository):
    if collectMode != "incr" or fullBackup:
       startRevision = 0
       endRevision = getYoungestRevision(repository.repositoryPath)
-      logger.debug("Using full backup, revision: (%d, %d)." % (startRevision, endRevision))
+      logger.debug("Using full backup, revision: (%d, %d).", startRevision, endRevision)
    else:
       if fullBackup:
          startRevision = 0
@@ -1242,9 +1242,9 @@ def _backupRepository(config, local, todayIsStart, fullBackup, repository):
          startRevision = _loadLastRevision(revisionPath) + 1
          endRevision = getYoungestRevision(repository.repositoryPath)
          if startRevision > endRevision:
-            logger.info("No need to back up repository [%s]; no new revisions." % repository.repositoryPath)
+            logger.info("No need to back up repository [%s]; no new revisions.", repository.repositoryPath)
             return
-      logger.debug("Using incremental backup, revision: (%d, %d)." % (startRevision, endRevision))
+      logger.debug("Using incremental backup, revision: (%d, %d).", startRevision, endRevision)
    backupPath = _getBackupPath(config, repository.repositoryPath, compressMode, startRevision, endRevision)
    outputFile = _getOutputFile(backupPath, compressMode)
    try:
@@ -1256,7 +1256,7 @@ def _backupRepository(config, local, todayIsStart, fullBackup, repository):
    changeOwnership(backupPath, config.options.backupUser, config.options.backupGroup)
    if collectMode == "incr":
       _writeLastRevision(config, revisionPath, endRevision)
-   logger.info("Completed backing up Subversion repository [%s]." % repository.repositoryPath)
+   logger.info("Completed backing up Subversion repository [%s].", repository.repositoryPath)
 
 def _getOutputFile(backupPath, compressMode):
    """
@@ -1294,14 +1294,14 @@ def _loadLastRevision(revisionPath):
    """
    if not os.path.isfile(revisionPath):
       startRevision = -1
-      logger.debug("Revision file [%s] does not exist on disk." % revisionPath)
+      logger.debug("Revision file [%s] does not exist on disk.", revisionPath)
    else:
       try:
          startRevision = pickle.load(open(revisionPath, "r"))
-         logger.debug("Loaded revision file [%s] from disk: %d." % (revisionPath, startRevision))
+         logger.debug("Loaded revision file [%s] from disk: %d.", revisionPath, startRevision)
       except:
          startRevision = -1
-         logger.error("Failed loading revision file [%s] from disk." % revisionPath)
+         logger.error("Failed loading revision file [%s] from disk.", revisionPath)
    return startRevision
 
 def _writeLastRevision(config, revisionPath, endRevision):
@@ -1318,9 +1318,9 @@ def _writeLastRevision(config, revisionPath, endRevision):
    try:
       pickle.dump(endRevision, open(revisionPath, "w"))
       changeOwnership(revisionPath, config.options.backupUser, config.options.backupGroup)
-      logger.debug("Wrote new revision file [%s] to disk: %d." % (revisionPath, endRevision))
+      logger.debug("Wrote new revision file [%s] to disk: %d.", revisionPath, endRevision)
    except:
-      logger.error("Failed to write revision file [%s] to disk." % revisionPath)
+      logger.error("Failed to write revision file [%s] to disk.", revisionPath)
 
 
 ##############################
@@ -1353,7 +1353,7 @@ def backupRepository(repositoryPath, backupFile, startRevision=None, endRevision
 
    @param backupFile: Python file object to use for writing backup.
    @type backupFile: Python file object as from C{open()} or C{file()}.
-   
+
    @param startRevision: Starting repository revision to back up (for incremental backups)
    @type startRevision: Integer value >= 0.
 
@@ -1378,7 +1378,7 @@ def backupRepository(repositoryPath, backupFile, startRevision=None, endRevision
    result = executeCommand(command, args, returnOutput=False, ignoreStderr=True, doNotLog=True, outputFile=backupFile)[0]
    if result != 0:
       raise IOError("Error [%d] executing Subversion dump for repository [%s]." % (result, repositoryPath))
-   logger.debug("Completed dumping subversion repository [%s]." % repositoryPath)
+   logger.debug("Completed dumping subversion repository [%s].", repositoryPath)
 
 
 #################################
@@ -1396,7 +1396,7 @@ def getYoungestRevision(repositoryPath):
    @type repositoryPath: String path representing Subversion repository on disk.
 
    @return: Youngest revision as an integer.
-   
+
    @raise ValueError: If there is a problem parsing the C{svnlook} output.
    @raise IOError: If there is a problem executing the C{svnlook} command.
    """
