@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: testutil.py 1023 2011-10-11 23:44:50Z pronovic $
 # Purpose  : Provides unit-testing utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -37,7 +36,7 @@
 ########################################################################
 
 """
-Provides unit-testing utilities. 
+Provides unit-testing utilities.
 
 These utilities are kept here, separate from util.py, because they provide
 common functionality that I do not want exported "publicly" once Cedar Backup
@@ -52,7 +51,7 @@ making them available to others.
 @sort: findResources, commandAvailable,
        buildPath, removedir, extractTar, changeFileAge,
        getMaskAsMode, getLogin, failUnlessAssignRaises, runningAsRoot,
-       platformDebian, platformMacOsX, platformCygwin, platformWindows, 
+       platformDebian, platformMacOsX, platformCygwin, platformWindows,
        platformHasEcho, platformSupportsLinks, platformSupportsPermissions,
        platformRequiresBinaryRead
 
@@ -102,7 +101,7 @@ def setupDebugLogger():
    logger = logging.getLogger("CedarBackup2")
    logger.setLevel(logging.DEBUG)    # let the logger see all messages
    formatter = logging.Formatter(fmt="%(message)s")
-   handler = logging.StreamHandler(strm=sys.stdout)
+   handler = logging.StreamHandler(stream=sys.stdout)
    handler.setFormatter(formatter)
    handler.setLevel(logging.DEBUG)
    logger.addHandler(handler)
@@ -119,7 +118,7 @@ def setupOverrides():
    When packages are built, this is done manually (hardcoded) in customize.py
    and the overrides are set up in cli.cli().  This way, no runtime checks need
    to be done.  This is safe, because the package maintainer knows exactly
-   which platform (Debian or not) the package is being built for.  
+   which platform (Debian or not) the package is being built for.
 
    Unit tests are different, because they might be run anywhere.  So, we
    attempt to make a guess about plaform using platformDebian(), and use that
@@ -202,7 +201,7 @@ def buildPath(components):
 def removedir(tree):
    """
    Recursively removes an entire directory.
-   This is basically taken from an example on python.com.  
+   This is basically taken from an example on python.com.
    @param tree: Directory tree to remove.
    @raise ValueError: If a path cannot be encoded properly.
    """
@@ -369,7 +368,7 @@ def failUnlessAssignRaises(testCase, exception, obj, prop, value):
       exec "obj.%s = value" % prop    # pylint: disable=W0122
       missed = True
    except exception: pass
-   except Exception, e: 
+   except Exception, e:
       instead = e
    if missed:
       testCase.fail("Expected assignment to raise %s, but got no exception." % (exception.__name__))
@@ -520,7 +519,7 @@ def platformHasEcho():
    On some platforms, like Windows, echo doesn't really work for tests.
    """
    return not platformWindows()
-   
+
 
 ###########################
 # runningAsRoot() function
